############
Installation
############

If you want to use the GUI version, grab the latest executable from the
`GitHub release page <https://github.com/bbtufty/romsearch/releases/latest>`_.
Alternatively, you can pip or pipx install (see below) then in the command line type
``romsearch`` to activate the GUI

ROMSearch is also pip-installable: ::

  pip install romsearch

Installable via pipx (this will bring up the GUI): ::

  pipx install romsearch
  romsearch

It can be installed via GitHub for the latest version: ::

  git clone https://github.com/bbtufty/romsearch.git
  cd romsearch
  pip install -e .

Or with pipx: ::

  git clone https://github.com/bbtufty/romsearch.git
  cd romsearch
  pipx install .
